* [gentoo-commits] proj/sci:master commit in: scripts/
@ 2011-07-29 17:46 Kacper Kowalik
0 siblings, 0 replies; 14+ messages in thread
From: Kacper Kowalik @ 2011-07-29 17:46 UTC (permalink / raw
To: gentoo-commits
commit: ee316412805320f3bfbeb1416ebea9eba4f4bb43
Author: Kacper Kowalik (Xarthisius) <xarthisius.kk <AT> gmail <DOT> com>
AuthorDate: Fri Jul 29 17:46:39 2011 +0000
Commit: Kacper Kowalik <xarthisius <AT> gentoo <DOT> org>
CommitDate: Fri Jul 29 17:46:39 2011 +0000
URL: http://git.overlays.gentoo.org/gitweb/?p=proj/sci.git;a=commit;h=ee316412
Add script for generating path64 snapshots
---
scripts/make_path64_snapshot.sh | 37 +++++++++++++++++++++++++++++++++++++
1 files changed, 37 insertions(+), 0 deletions(-)
diff --git a/scripts/make_path64_snapshot.sh b/scripts/make_path64_snapshot.sh
new file mode 100644
index 0000000..3592495
--- /dev/null
+++ b/scripts/make_path64_snapshot.sh
@@ -0,0 +1,37 @@
+#!/bin/bash
+
+clean_git() {
+ for f in $(find ./"$1" -name ".git"); do rm -rf $f; done
+}
+
+TEMP=/dev/shm/path64
+TODAY=$(date -u +%Y%m%d)
+
+[[ -d ${TEMP} ]] && rm -rf ${TEMP}
+mkdir "${TEMP}" && cd "${TEMP}"
+
+git clone git://github.com/pathscale/path64-suite.git path64
+clean_git path64
+ver=$(grep 'SET(PSC_FULL_VERSION' path64/CMakeLists.txt | cut -d'"' -f2)
+tar cjf path64-suite-${ver}_pre${TODAY}.tbz2 path64
+
+[[ -d ${TEMP}/path64/compiler ]] || mkdir -p ${TEMP}/path64/compiler
+cd ${TEMP}/path64/compiler
+
+for f in compiler assembler ; do
+ git clone git://github.com/path64/$f.git
+done
+git clone git://github.com/path64/debugger.git pathdb
+for f in compiler-rt libcxxrt libdwarf-bsd libunwind stdcxx ; do
+ git clone git://github.com/pathscale/$f.git
+done
+
+clean_git
+cd "${TEMP}"
+tar cjf path64-compiler-${ver}_pre${TODAY}.tbz2 \
+ path64/compiler/{compiler,compiler-rt,libcxxrt,libdwarf-bsd,libunwind,stdcxx}
+tar cjf path64-debugger-${ver}_pre${TODAY}.tbz2 \
+ path64/compiler/pathdb
+tar cjf path64-assembler-${ver}_pre${TODAY}.tbz2 \
+ path64/compiler/assembler
+
^ permalink raw reply related [flat|nested] 14+ messages in thread
* [gentoo-commits] proj/sci:master commit in: scripts/
@ 2014-01-28 19:46 Sebastien Fabbro
0 siblings, 0 replies; 14+ messages in thread
From: Sebastien Fabbro @ 2014-01-28 19:46 UTC (permalink / raw
To: gentoo-commits
commit: 493e185159674b34faf859c0ba470f431bf9eac9
Author: Justin Lecher <jlec <AT> gentoo <DOT> org>
AuthorDate: Wed Jan 22 10:43:38 2014 +0000
Commit: Sebastien Fabbro <bicatali <AT> gentoo <DOT> org>
CommitDate: Wed Jan 22 10:44:05 2014 +0000
URL: http://git.overlays.gentoo.org/gitweb/?p=proj/sci.git;a=commit;h=493e1851
Set license to BSD-3
Signed-off-by: Justin Lecher <jlec <AT> gentoo.org>
---
scripts/merge-dualHEAD | 1 +
1 file changed, 1 insertion(+)
diff --git a/scripts/merge-dualHEAD b/scripts/merge-dualHEAD
index c926881..ca05ee4 100755
--- a/scripts/merge-dualHEAD
+++ b/scripts/merge-dualHEAD
@@ -1,4 +1,5 @@
#!/bin/bash
+# This script is licensed under BSD-3
if [[ -f /usr/lib64/portage/bin/isolated-functions.sh ]]; then
. /usr/lib64/portage/bin/isolated-functions.sh
^ permalink raw reply related [flat|nested] 14+ messages in thread
* [gentoo-commits] proj/sci:master commit in: scripts/
@ 2014-01-28 19:46 Sebastien Fabbro
0 siblings, 0 replies; 14+ messages in thread
From: Sebastien Fabbro @ 2014-01-28 19:46 UTC (permalink / raw
To: gentoo-commits
commit: 5444c1b59b5ffd2c2f783cb21eb3ba3ae86440b1
Author: Justin Lecher <jlec <AT> gentoo <DOT> org>
AuthorDate: Wed Jan 22 10:42:34 2014 +0000
Commit: Sebastien Fabbro <bicatali <AT> gentoo <DOT> org>
CommitDate: Wed Jan 22 10:44:05 2014 +0000
URL: http://git.overlays.gentoo.org/gitweb/?p=proj/sci.git;a=commit;h=5444c1b5
Import script, original idea by alexxy
Signed-off-by: Justin Lecher <jlec <AT> gentoo.org>
---
scripts/merge-dualHEAD | 63 ++++++++++++++++++++++++++++++++++++++++++++++++++
1 file changed, 63 insertions(+)
diff --git a/scripts/merge-dualHEAD b/scripts/merge-dualHEAD
new file mode 100755
index 0000000..c926881
--- /dev/null
+++ b/scripts/merge-dualHEAD
@@ -0,0 +1,63 @@
+#!/bin/bash
+
+if [[ -f /usr/lib64/portage/bin/isolated-functions.sh ]]; then
+ . /usr/lib64/portage/bin/isolated-functions.sh
+elif [[ -f /usr/lib/portage/bin/isolated-functions.sh ]]; then
+ . /usr/lib/portage/bin/isolated-functions.sh
+else
+ alias ebegin=echo
+ alias eend=true
+fi
+
+ebegin "Starting from master"
+ echo
+ git checkout master || exit; _ret=$?
+ echo
+eend ${_ret}
+
+ebegin "Fetching everything"
+ echo
+ git fetch --all -v || exit; _ret=$?
+ echo
+eend ${_ret}
+
+ebegin "Merging github"
+ echo
+ git merge -v github/master || exit; _ret=$?
+ echo
+eend ${_ret}
+
+ebegin "Pushing to g.o.g.o"
+ git push -v origin || exit; _ret=$?
+ echo
+eend ${_ret}
+
+ebegin "Branching out github"
+ echo
+ git checkout -b github-merging github/master || exit; _ret=$?
+ echo
+eend ${_ret}
+
+ebegin "Merging in g.o.g.o"
+ echo
+ git merge -v origin/master || exit; _ret=$?
+ echo
+eend ${_ret}
+
+ebegin "Pushing to github"
+ echo
+ git push -v github HEAD:master || exit; _ret=$?
+ echo
+eend ${_ret}
+
+ebegin "Going back to master"
+ echo
+ git checkout master || exit; _ret=$?
+ echo
+eend ${_ret}
+
+ebegin "Removing github branch"
+ echo
+ git branch -v -D github-merging || exit; _ret=$?
+ echo
+eend ${_ret}
^ permalink raw reply related [flat|nested] 14+ messages in thread
* [gentoo-commits] proj/sci:master commit in: scripts/
@ 2014-09-18 20:40 Justin Lecher
0 siblings, 0 replies; 14+ messages in thread
From: Justin Lecher @ 2014-09-18 20:40 UTC (permalink / raw
To: gentoo-commits
commit: 46bc533f719847da8a98d7a98a9fc5979d4dff23
Author: Justin Lecher <jlec <AT> gentoo <DOT> org>
AuthorDate: Thu Sep 18 20:40:36 2014 +0000
Commit: Justin Lecher <jlec <AT> gentoo <DOT> org>
CommitDate: Thu Sep 18 20:40:36 2014 +0000
URL: http://sources.gentoo.org/gitweb/?p=proj/sci.git;a=commit;h=46bc533f
Update to latest portage versions
Signed-off-by: Justin Lecher <jlec <AT> gentoo.org>
---
scripts/merge-dualHEAD | 8 ++++----
1 file changed, 4 insertions(+), 4 deletions(-)
diff --git a/scripts/merge-dualHEAD b/scripts/merge-dualHEAD
index ca05ee4..961b461 100755
--- a/scripts/merge-dualHEAD
+++ b/scripts/merge-dualHEAD
@@ -1,10 +1,10 @@
#!/bin/bash
# This script is licensed under BSD-3
-if [[ -f /usr/lib64/portage/bin/isolated-functions.sh ]]; then
- . /usr/lib64/portage/bin/isolated-functions.sh
-elif [[ -f /usr/lib/portage/bin/isolated-functions.sh ]]; then
- . /usr/lib/portage/bin/isolated-functions.sh
+export PORTAGE_BIN_PATH="/usr/lib64/portage/python2.7"
+
+if [[ -f "${PORTAGE_BIN_PATH}"/isolated-functions.sh ]]; then
+ . "${PORTAGE_BIN_PATH}"/isolated-functions.sh
else
alias ebegin=echo
alias eend=true
^ permalink raw reply related [flat|nested] 14+ messages in thread
* [gentoo-commits] proj/sci:master commit in: scripts/
@ 2015-01-01 15:33 Andrew Savchenko
0 siblings, 0 replies; 14+ messages in thread
From: Andrew Savchenko @ 2015-01-01 15:33 UTC (permalink / raw
To: gentoo-commits
commit: 579e25454b12e266fffc10f48e62be4155522e0b
Author: Andrew Savchenko <bircoph <AT> gentoo <DOT> org>
AuthorDate: Thu Jan 1 15:32:16 2015 +0000
Commit: Andrew Savchenko <bircoph <AT> gmail <DOT> com>
CommitDate: Thu Jan 1 15:32:16 2015 +0000
URL: http://sources.gentoo.org/gitweb/?p=proj/sci.git;a=commit;h=579e2545
Use /usr/lib instead of /usr/lib64
Not all people commit from 64-bit hosts, so lib64 brokes script for
them. /usr/lib should be safe, as it should symlink to current main
API on the system.
---
scripts/merge-dualHEAD | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/scripts/merge-dualHEAD b/scripts/merge-dualHEAD
index 961b461..43b7610 100755
--- a/scripts/merge-dualHEAD
+++ b/scripts/merge-dualHEAD
@@ -1,7 +1,7 @@
#!/bin/bash
# This script is licensed under BSD-3
-export PORTAGE_BIN_PATH="/usr/lib64/portage/python2.7"
+export PORTAGE_BIN_PATH="/usr/lib/portage/python2.7"
if [[ -f "${PORTAGE_BIN_PATH}"/isolated-functions.sh ]]; then
. "${PORTAGE_BIN_PATH}"/isolated-functions.sh
^ permalink raw reply related [flat|nested] 14+ messages in thread
* [gentoo-commits] proj/sci:master commit in: scripts/
@ 2018-08-19 22:23 Horea Christian
0 siblings, 0 replies; 14+ messages in thread
From: Horea Christian @ 2018-08-19 22:23 UTC (permalink / raw
To: gentoo-commits
commit: e1d64388e03e18ab8fefa06031c7e75956108004
Author: Horea Christian <horea.christ <AT> yandex <DOT> com>
AuthorDate: Sun Aug 19 22:23:11 2018 +0000
Commit: Horea Christian <horea.christ <AT> gmail <DOT> com>
CommitDate: Sun Aug 19 22:23:11 2018 +0000
URL: https://gitweb.gentoo.org/proj/sci.git/commit/?id=e1d64388
corrected path
scripts/{lapack_migration.sh => lapack-migration.sh} | 0
1 file changed, 0 insertions(+), 0 deletions(-)
diff --git a/scripts/lapack_migration.sh b/scripts/lapack-migration.sh
similarity index 100%
rename from scripts/lapack_migration.sh
rename to scripts/lapack-migration.sh
^ permalink raw reply [flat|nested] 14+ messages in thread
* [gentoo-commits] proj/sci:master commit in: scripts/
@ 2018-11-27 20:48 Horea Christian
0 siblings, 0 replies; 14+ messages in thread
From: Horea Christian @ 2018-11-27 20:48 UTC (permalink / raw
To: gentoo-commits
commit: 3cfd08050c5560e85ea48e20f6ec4fbaa669af85
Author: Horea Christian <horea.christ <AT> gmail <DOT> com>
AuthorDate: Tue Nov 27 14:39:09 2018 +0000
Commit: Horea Christian <horea.christ <AT> gmail <DOT> com>
CommitDate: Tue Nov 27 20:17:15 2018 +0000
URL: https://gitweb.gentoo.org/proj/sci.git/commit/?id=3cfd0805
Meta: added run permission
Signed-off-by: Horea Christian <horea.christ <AT> yandex.com>
scripts/lapack-migration.sh | 0
1 file changed, 0 insertions(+), 0 deletions(-)
diff --git a/scripts/lapack-migration.sh b/scripts/lapack-migration.sh
old mode 100644
new mode 100755
^ permalink raw reply [flat|nested] 14+ messages in thread
* [gentoo-commits] proj/sci:master commit in: scripts/
@ 2019-01-11 10:57 Horea Christian
0 siblings, 0 replies; 14+ messages in thread
From: Horea Christian @ 2019-01-11 10:57 UTC (permalink / raw
To: gentoo-commits
commit: b32dcf129e8e30e28dd78ba1faebd135ea217100
Author: Horea Christian <horea.christ <AT> yandex <DOT> com>
AuthorDate: Fri Jan 11 10:50:48 2019 +0000
Commit: Horea Christian <horea.christ <AT> gmail <DOT> com>
CommitDate: Fri Jan 11 10:54:25 2019 +0000
URL: https://gitweb.gentoo.org/proj/sci.git/commit/?id=b32dcf12
Checking for and creating config dir if needed
and improved comment style and grammar
Signed-off-by: Horea Christian <horea.christ <AT> yandex.com>
scripts/lapack-migration.sh | 5 ++++-
1 file changed, 4 insertions(+), 1 deletion(-)
diff --git a/scripts/lapack-migration.sh b/scripts/lapack-migration.sh
index 2e6624ada..cd932c130 100755
--- a/scripts/lapack-migration.sh
+++ b/scripts/lapack-migration.sh
@@ -3,11 +3,14 @@ set -e
EPREFIX=${1}
-#Link to the workaroud we reproduce in this section : https://wiki.gentoo.org/wiki/User_talk:Houseofsuns#Migration_to_science_overlay_from_main_tree
+#Link to the workaround automated by this script: https://wiki.gentoo.org/wiki/User_talk:Houseofsuns#Migration_to_science_overlay_from_main_tree
#Efforts to more permanently address the issue: https://github.com/gentoo/sci/issues/805
echo ""
echo "Setting Up Eselect for Gentoo Science:"
echo "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~"
+if [ ! -d ${EPREFIX}/etc/portage/package.mask/ ]; then
+ mkdir -p ${EPREFIX}/etc/portage/package.mask/;
+fi
cp "sci-lapack" "${EPREFIX}/etc/portage/package.mask/"
emerge --oneshot --verbose dev-util/cmake >> /dev/null
emerge --oneshot --verbose app-admin/eselect::science >> /dev/null
^ permalink raw reply related [flat|nested] 14+ messages in thread
* [gentoo-commits] proj/sci:master commit in: scripts/
@ 2021-02-17 19:47 Andrew Ammerlaan
0 siblings, 0 replies; 14+ messages in thread
From: Andrew Ammerlaan @ 2021-02-17 19:47 UTC (permalink / raw
To: gentoo-commits
commit: cd8abc7a0819ceb9913bb8c3f0c2a8164f9e826f
Author: Andrew Ammerlaan <andrewammerlaan <AT> riseup <DOT> net>
AuthorDate: Wed Feb 17 19:47:06 2021 +0000
Commit: Andrew Ammerlaan <andrewammerlaan <AT> riseup <DOT> net>
CommitDate: Wed Feb 17 19:47:06 2021 +0000
URL: https://gitweb.gentoo.org/proj/sci.git/commit/?id=cd8abc7a
scripts/check-duplicates.sh: s/guru/science/g
Signed-off-by: Andrew Ammerlaan <andrewammerlaan <AT> riseup.net>
scripts/check-duplicates.sh | 28 ++++++++++++++--------------
1 file changed, 14 insertions(+), 14 deletions(-)
diff --git a/scripts/check-duplicates.sh b/scripts/check-duplicates.sh
index 47a4a12f1..85af7839c 100755
--- a/scripts/check-duplicates.sh
+++ b/scripts/check-duplicates.sh
@@ -1,76 +1,77 @@
-#!/usr/bin/env bash
+#! /usr/bin/env bash
# Maintainer: Andrew Ammerlaan <andrewammerlaan@riseup.net>
+# Maintainer: Theo Anderson <telans@posteo.de>
#
-# This checks if packages in ::science are also in ::gentoo
-#
+# This checks for potential and exact package matches within an overlay & ::gentoo
# Note that this is not going to be 100% accurate
#
-#
-
-printf "\nChecking for duplicates....\n"
-gentoo_location="/var/db/repos/gentoo"
-science_location="."
+GENTOO_DIR="/var/db/repos/gentoo"
+GENTOO_PACKAGES=(
+ $(find ${GENTOO_DIR} -mindepth 2 -maxdepth 2 -printf "%P\n" \
+ | sort | grep -Ev "^(.git|.github|metadata|profiles|scripts)/"
+ )
+)
+REPO_PACKAGES=(
+ $(find . -mindepth 2 -maxdepth 2 -printf "%P\n" \
+ | sort | grep -Ev "^(.git|.github|metadata|profiles|scripts)/"
+ )
+)
-gentoo_packs=$(find ${gentoo_location} -mindepth 2 -maxdepth 2 -printf "%P\n" | sort | grep -Ev "^(.git|.github|metadata|profiles|scripts)/")
-science_packs=$(find ${science_location} -mindepth 2 -maxdepth 2 -printf "%P\n" | sort | grep -Ev "^(.git|.github|metadata|profiles|scripts)/")
+REPO_NAME="$(cat profiles/repo_name)"
-pack_overrides="" pack_close_match_in_cat="" pack_close_match=""
-for science_pack in ${science_packs}; do
- # separate category and packages
- science_pack_cat="${science_pack%%/*}"
- science_pack_name="${science_pack##*/}"
+printf "\nChecking for duplicates...\n"
- # convert all to lowercase
- science_pack_name="${science_pack_name,,}"
-
- # stip all numbers, dashes, underscores and pluses
- science_pack_name="${science_pack_name/[0-9-_+]}"
-
- for gentoo_pack in ${gentoo_packs}; do
- # separate category and packages
- gentoo_pack_cat="${gentoo_pack%%/*}"
- gentoo_pack_name="${gentoo_pack##*/}"
+for GENTOO_PKG in ${GENTOO_PACKAGES[@]}; do
+ GENTOO_CATEGORIES+=( ${GENTOO_PKG%%/*} ) # Separate category
+ GENTOO_PKG_NAME=${GENTOO_PKG##*/} # Separate name
+ GENTOO_PKG_NAME=${GENTOO_PKG_NAME,,} # Force lower case, e.g. to match foobar and FooBar
+ GENTOO_PKG_NAME=${GENTOO_PKG_NAME/[-_]} # Remove underscores and dashes, e.g. to match foo-bar and foo_bar
+ GENTOO_PKG_NAMES+=( ${GENTOO_PKG_NAME} )
+done
- # convert all to lowercase
- gentoo_pack_name="${gentoo_pack_name,,}"
+printf "Testing ${#REPO_PACKAGES[@]} ${REPO_NAME^} packages against ${#GENTOO_PKG_NAMES[@]} Gentoo packages\n"
- # stip all numbers, dashes, underscores and pluses
- gentoo_pack_name="${gentoo_pack_name/[0-9-_+]}"
+for REPO_PKG in ${REPO_PACKAGES[@]}; do
+ REPO_PKG_CATEGORY=${REPO_PKG%%/*}
+ REPO_PKG_NAME=${REPO_PKG##*/}
+ REPO_PKG_NAME=${REPO_PKG_NAME,,}
+ REPO_PKG_NAME=${REPO_PKG_NAME/[-_]}
- #TODO: check DESCRIPTION, HOMEPAGE and SRC_URI for close matches
+ if [[ ${GENTOO_PKG_NAMES[@]} =~ " ${REPO_PKG_NAME} " ]]; then # Check for a matcing name in the Gentoo tree,
+ for (( i=0; i<${#GENTOO_PKG_NAMES[@]}; i++ )); do # otherwise there is no need to continue
+ [[ ${GENTOO_PKG_NAMES[$i]} == ${REPO_PKG_NAME} ]] && index+=( $i ) # Find the category/index for multiple matching names
+ done
- if [[ "${gentoo_pack_name}" == "${science_pack_name}" ]]; then
- if [[ "${gentoo_pack_cat}" == "${science_pack_cat}" ]]; then
- if [[ "${gentoo_pack}" == "${science_pack}" ]]; then
- pack_overrides+="\t${science_pack}::science exact match of ${gentoo_pack}::gentoo\n"
- else
- pack_close_match_in_cat+="\t${science_pack}::science possible duplicate of ${gentoo_pack}::gentoo\n"
- fi
- else
- pack_close_match+="\t${science_pack}::science possible duplicate of ${gentoo_pack}::gentoo\n"
+ for i in ${index[@]}; do # For each possible match
+ if [[ ${GENTOO_PACKAGES[$i]} == ${REPO_PKG} ]]; then
+ PKG_EXACT_MATCH+="\t${REPO_PKG}::${REPO_NAME} exact match of ${GENTOO_PACKAGES[$i]}::gentoo\n"
+ break # An exact match is fatal, no need to continue
+ elif [[ ${GENTOO_CATEGORIES[$i]} == ${REPO_PKG_CATEGORY} ]]; then # Possible match within the same category
+ PKG_CATEGORY_MATCH+="\t${REPO_PKG}::${REPO_NAME} possible duplicate of ${GENTOO_PACKAGES[$i]}::gentoo\n"
+ else # Possible match in a different category
+ PKG_SPECULATIVE_MATCH+="\t${REPO_PKG}::${REPO_NAME} possible duplicate of ${GENTOO_PACKAGES[$i]}::gentoo\n"
fi
- fi
- done
+ done
+ unset index
+ fi
done
-if [ -n "${pack_close_match}" ]; then
- printf "\nWARNING: The following packages closely match packages in the main Gentoo repository\n"
- printf "${pack_close_match}"
- printf "Please check these manually\n"
+if [[ -n ${PKG_SPECULATIVE_MATCH} ]]; then
+ printf "\nWARNING: The following packages closely match packages in the main Gentoo repository:\n"
+ printf "${PKG_SPECULATIVE_MATCH}"
+ printf "Please check these manually.\n"
fi
-if [ -n "${pack_close_match_in_cat}" ]; then
- printf "\nWARNING: The following packages closely match packages in the main Gentoo repository in the same category\n"
- printf "${pack_close_match_in_cat}"
- printf "Please check these manually\n"
+if [[ -n ${PKG_CATEGORY_MATCH} ]]; then
+ printf "\nWARNING: The following packages closely match packages in the main Gentoo repository, in the same category:\n"
+ printf "${PKG_CATEGORY_MATCH}"
+ printf "Please check these manually.\n"
fi
-if [ -n "${pack_overrides}" ]; then
- printf "\nERROR: The following packages override packages in the main Gentoo repository\n"
- printf "${pack_overrides}"
- printf "Please remove these packages\n"
- # do not exit fatally on ::science
- # exit 1
+if [[ -n ${PKG_EXACT_MATCH} ]]; then
+ printf "\nERROR: The following packages override packages in the main Gentoo repository:\n"
+ printf "${PKG_EXACT_MATCH}"
+ printf "Please remove these packages.\n"
+ exit 1
fi
-exit 0
^ permalink raw reply related [flat|nested] 14+ messages in thread
* [gentoo-commits] proj/sci:master commit in: scripts/
@ 2021-02-18 11:11 Andrew Ammerlaan
0 siblings, 0 replies; 14+ messages in thread
From: Andrew Ammerlaan @ 2021-02-18 11:11 UTC (permalink / raw
To: gentoo-commits
commit: 703d25f5fffc66325be8e0489c576ff1fb502712
Author: Andrew Ammerlaan <andrewammerlaan <AT> riseup <DOT> net>
AuthorDate: Thu Feb 18 11:11:24 2021 +0000
Commit: Andrew Ammerlaan <andrewammerlaan <AT> riseup <DOT> net>
CommitDate: Thu Feb 18 11:11:24 2021 +0000
URL: https://gitweb.gentoo.org/proj/sci.git/commit/?id=703d25f5
scripts/check-duplicates.sh: do not fatally exit
Signed-off-by: Andrew Ammerlaan <andrewammerlaan <AT> riseup.net>
scripts/check-duplicates.sh | 3 ++-
1 file changed, 2 insertions(+), 1 deletion(-)
diff --git a/scripts/check-duplicates.sh b/scripts/check-duplicates.sh
index 85af7839c..378333767 100755
--- a/scripts/check-duplicates.sh
+++ b/scripts/check-duplicates.sh
@@ -73,5 +73,6 @@ if [[ -n ${PKG_EXACT_MATCH} ]]; then
printf "\nERROR: The following packages override packages in the main Gentoo repository:\n"
printf "${PKG_EXACT_MATCH}"
printf "Please remove these packages.\n"
- exit 1
+ # do not fatally exit
+ # exit 1
fi
^ permalink raw reply related [flat|nested] 14+ messages in thread
* [gentoo-commits] proj/sci:master commit in: scripts/
@ 2021-02-18 18:43 Andrew Ammerlaan
0 siblings, 0 replies; 14+ messages in thread
From: Andrew Ammerlaan @ 2021-02-18 18:43 UTC (permalink / raw
To: gentoo-commits
commit: e8a40cc727636417091fe6b7633bb823247c0a66
Author: Andrew Ammerlaan <andrewammerlaan <AT> riseup <DOT> net>
AuthorDate: Thu Feb 18 18:43:03 2021 +0000
Commit: Andrew Ammerlaan <andrewammerlaan <AT> riseup <DOT> net>
CommitDate: Thu Feb 18 18:43:03 2021 +0000
URL: https://gitweb.gentoo.org/proj/sci.git/commit/?id=e8a40cc7
scripts/check-duplicates.sh: skip categories metadata.xml
Signed-off-by: Andrew Ammerlaan <andrewammerlaan <AT> riseup.net>
scripts/check-duplicates.sh | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/scripts/check-duplicates.sh b/scripts/check-duplicates.sh
index 378333767..d8e56463e 100755
--- a/scripts/check-duplicates.sh
+++ b/scripts/check-duplicates.sh
@@ -9,12 +9,12 @@
GENTOO_DIR="/var/db/repos/gentoo"
GENTOO_PACKAGES=(
$(find ${GENTOO_DIR} -mindepth 2 -maxdepth 2 -printf "%P\n" \
- | sort | grep -Ev "^(.git|.github|metadata|profiles|scripts)/"
+ | sort | grep -Ev "^(.git|.github|metadata|profiles|scripts)/|metadata.xml"
)
)
REPO_PACKAGES=(
$(find . -mindepth 2 -maxdepth 2 -printf "%P\n" \
- | sort | grep -Ev "^(.git|.github|metadata|profiles|scripts)/"
+ | sort | grep -Ev "^(.git|.github|metadata|profiles|scripts)/|metadata.xml"
)
)
^ permalink raw reply related [flat|nested] 14+ messages in thread
* [gentoo-commits] proj/sci:master commit in: scripts/
@ 2021-06-15 6:56 Andrew Ammerlaan
0 siblings, 0 replies; 14+ messages in thread
From: Andrew Ammerlaan @ 2021-06-15 6:56 UTC (permalink / raw
To: gentoo-commits
commit: 5ddaec4db70483bff1a83cef04af84cee7e5e1c1
Author: Yuan Liao <liaoyuan <AT> gmail <DOT> com>
AuthorDate: Mon Jun 14 20:22:34 2021 +0000
Commit: Andrew Ammerlaan <andrewammerlaan <AT> gentoo <DOT> org>
CommitDate: Tue Jun 15 06:55:31 2021 +0000
URL: https://gitweb.gentoo.org/proj/sci.git/commit/?id=5ddaec4d
scripts/setup-and-run-repoman.sh: use 'sort -V' to get latest tag
Without the -V flag to enable version sort, 'sort' can falsely identify
a version string like 3.0.9 to be greater than 3.0.10. This can be
shown by running 'git tag | grep portage | sort -u' in the Portage Git
tree. This issue is not so prominent for repoman yet because the latest
version of repoman as of now is 3.0.3, but it will surface when repoman
3.0.10 is released.
Signed-off-by: Yuan Liao <liaoyuan <AT> gmail.com>
Closes: https://github.com/gentoo/sci/pull/1094
Signed-off-by: Andrew Ammerlaan <andrewammerlaan <AT> gentoo.org>
scripts/setup-and-run-repoman.sh | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/scripts/setup-and-run-repoman.sh b/scripts/setup-and-run-repoman.sh
index f9e45a9cf..471a05181 100755
--- a/scripts/setup-and-run-repoman.sh
+++ b/scripts/setup-and-run-repoman.sh
@@ -16,7 +16,7 @@ git clone https://github.com/gentoo/portage.git
cd portage
# Get all versions, and read into array
-mapfile -t RM_VERSIONS < <( git tag | grep repoman | sort -u )
+mapfile -t RM_VERSIONS < <( git tag | grep repoman | sort -uV )
# Select latests version (last element in array)
RM_VERS="${RM_VERSIONS[-1]}"
^ permalink raw reply related [flat|nested] 14+ messages in thread
* [gentoo-commits] proj/sci:master commit in: scripts/
@ 2021-06-17 6:44 Andrew Ammerlaan
0 siblings, 0 replies; 14+ messages in thread
From: Andrew Ammerlaan @ 2021-06-17 6:44 UTC (permalink / raw
To: gentoo-commits
commit: 57035832a39a9a9b5daa9627feb44b4b53e4cf99
Author: Andrew Ammerlaan <andrewammerlaan <AT> gentoo <DOT> org>
AuthorDate: Thu Jun 17 06:43:28 2021 +0000
Commit: Andrew Ammerlaan <andrewammerlaan <AT> gentoo <DOT> org>
CommitDate: Thu Jun 17 06:43:28 2021 +0000
URL: https://gitweb.gentoo.org/proj/sci.git/commit/?id=57035832
scripts/setup-and-run-repoman.sh: checkout portage tag
checking out any current repoman version tag puts portage
into a version where EAPI 8 support is not enabled
Co-authored-by: Theo Anderson <telans <AT> posteo.de>
Signed-off-by: Andrew Ammerlaan <andrewammerlaan <AT> gentoo.org>
scripts/setup-and-run-repoman.sh | 2 +-
1 file changed, 1 insertion(+), 1 deletion(-)
diff --git a/scripts/setup-and-run-repoman.sh b/scripts/setup-and-run-repoman.sh
index 471a05181..e2e10c78e 100755
--- a/scripts/setup-and-run-repoman.sh
+++ b/scripts/setup-and-run-repoman.sh
@@ -16,7 +16,7 @@ git clone https://github.com/gentoo/portage.git
cd portage
# Get all versions, and read into array
-mapfile -t RM_VERSIONS < <( git tag | grep repoman | sort -uV )
+mapfile -t RM_VERSIONS < <( git tag | grep portage | sort -uV )
# Select latests version (last element in array)
RM_VERS="${RM_VERSIONS[-1]}"
^ permalink raw reply related [flat|nested] 14+ messages in thread
end of thread, other threads:[~2021-06-17 6:44 UTC | newest]
Thread overview: 14+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2021-06-17 6:44 [gentoo-commits] proj/sci:master commit in: scripts/ Andrew Ammerlaan
-- strict thread matches above, loose matches on Subject: below --
2021-06-15 6:56 Andrew Ammerlaan
2021-02-18 18:43 Andrew Ammerlaan
2021-02-18 11:11 Andrew Ammerlaan
2021-02-18 11:10 Andrew Ammerlaan
2021-02-17 19:47 Andrew Ammerlaan
2019-01-11 10:57 Horea Christian
2018-11-27 20:48 Horea Christian
2018-08-19 22:23 Horea Christian
2015-01-01 15:33 Andrew Savchenko
2014-09-18 20:40 Justin Lecher
2014-01-28 19:46 Sebastien Fabbro
2014-01-28 19:46 Sebastien Fabbro
2011-07-29 17:46 Kacper Kowalik
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
diff --git a/scripts/check-duplicates.sh b/scripts/check-duplicates.sh
index 8f6b89af7..47a4a12f1 100755
--- a/scripts/check-duplicates.sh
+++ b/scripts/check-duplicates.sh
@@ -1,7 +1,7 @@
#!/usr/bin/env bash
# Maintainer: Andrew Ammerlaan <andrewammerlaan@riseup.net>
#
# This checks if packages in ::guru are also in ::gentoo
#
# Note that this is not going to be 100% accurate
#
@@ -10,22 +10,22 @@
printf "\nChecking for duplicates....\n"
gentoo_location="/var/db/repos/gentoo"
-guru_location="."
+science_location="."
gentoo_packs=$(find ${gentoo_location} -mindepth 2 -maxdepth 2 -printf "%P\n" | sort | grep -Ev "^(.git|.github|metadata|profiles|scripts)/")
-guru_packs=$(find ${guru_location} -mindepth 2 -maxdepth 2 -printf "%P\n" | sort | grep -Ev "^(.git|.github|metadata|profiles|scripts)/")
+science_packs=$(find ${science_location} -mindepth 2 -maxdepth 2 -printf "%P\n" | sort | grep -Ev "^(.git|.github|metadata|profiles|scripts)/")
pack_overrides="" pack_close_match_in_cat="" pack_close_match=""
-for guru_pack in ${guru_packs}; do
+for science_pack in ${science_packs}; do
# separate category and packages
- guru_pack_cat="${guru_pack%%/*}"
- guru_pack_name="${guru_pack##*/}"
+ science_pack_cat="${science_pack%%/*}"
+ science_pack_name="${science_pack##*/}"
# convert all to lowercase
- guru_pack_name="${guru_pack_name,,}"
+ science_pack_name="${science_pack_name,,}"
# stip all numbers, dashes, underscores and pluses
- guru_pack_name="${guru_pack_name/[0-9-_+]}"
+ science_pack_name="${science_pack_name/[0-9-_+]}"
for gentoo_pack in ${gentoo_packs}; do
# separate category and packages
@@ -40,15 +40,15 @@ for guru_pack in ${guru_packs}; do
#TODO: check DESCRIPTION, HOMEPAGE and SRC_URI for close matches
- if [[ "${gentoo_pack_name}" == "${guru_pack_name}" ]]; then
- if [[ "${gentoo_pack_cat}" == "${guru_pack_cat}" ]]; then
- if [[ "${gentoo_pack}" == "${guru_pack}" ]]; then
- pack_overrides+="\t${guru_pack}::guru exact match of ${gentoo_pack}::gentoo\n"
+ if [[ "${gentoo_pack_name}" == "${science_pack_name}" ]]; then
+ if [[ "${gentoo_pack_cat}" == "${science_pack_cat}" ]]; then
+ if [[ "${gentoo_pack}" == "${science_pack}" ]]; then
+ pack_overrides+="\t${science_pack}::science exact match of ${gentoo_pack}::gentoo\n"
else
- pack_close_match_in_cat+="\t${guru_pack}::guru possible duplicate of ${gentoo_pack}::gentoo\n"
+ pack_close_match_in_cat+="\t${science_pack}::science possible duplicate of ${gentoo_pack}::gentoo\n"
fi
else
- pack_close_match+="\t${guru_pack}::guru possible duplicate of ${gentoo_pack}::gentoo\n"
+ pack_close_match+="\t${science_pack}::science possible duplicate of ${gentoo_pack}::gentoo\n"
fi
fi
done
^ permalink raw reply related [flat|nested] 14+ messages in thread
* [gentoo-commits] proj/sci:master commit in: scripts/
@ 2021-02-18 11:10 Andrew Ammerlaan
0 siblings, 0 replies; 14+ messages in thread
From: Andrew Ammerlaan @ 2021-02-18 11:10 UTC (permalink / raw
To: gentoo-commits
@@ -1,7 +1,7 @@
# Maintainer: Andrew Ammerlaan <andrewammerlaan@riseup.net>
#
-# This checks if packages in ::guru are also in ::gentoo
+# This checks if packages in ::science are also in ::gentoo
#
# Note that this is not going to be 100% accurate
commit: ebbdcf28214532dc78f46b3f5b1c730f02a8ce1f
Author: Andrew Ammerlaan <andrewammerlaan <AT> riseup <DOT> net>
AuthorDate: Thu Feb 18 11:09:58 2021 +0000
Commit: Andrew Ammerlaan <andrewammerlaan <AT> riseup <DOT> net>
CommitDate: Thu Feb 18 11:09:58 2021 +0000
URL: https://gitweb.gentoo.org/proj/sci.git/commit/?id=ebbdcf28
scripts/check-duplicates.sh: backport improvements from ::guru
Signed-off-by: Andrew Ammerlaan <andrewammerlaan <AT> riseup.net>
scripts/check-duplicates.sh | 113 ++++++++++++++++++++++----------------------
1 file changed, 57 insertions(+), 56 deletions(-)